==> kubernetes-model-apiextensions-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1beta1/CustomResourceColumnDefinitionBuilder.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class CustomResourceColumnDefinitionBuilder extends CustomResourceColumnDefinitionFluentImpl<CustomResourceColumnDefinitionBuilder> implements VisitableBuilder<CustomResourceColumnDefinition,CustomResourceColumnDefinitionBuilder>{
  public CustomResourceColumnDefinitionBuilder() {
    this(false);
  }
  public CustomResourceColumnDefinitionBuilder(Boolean validationEnabled) {
    this(new CustomResourceColumnDefinition(), validationEnabled);
  }
  public CustomResourceColumnDefinitionBuilder(CustomResourceColumnDefinitionFluent<?> fluent) {
    this(fluent, false);
  }
  public CustomResourceColumnDefinitionBuilder(CustomResourceColumnDefinitionFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new CustomResourceColumnDefinition(), validationEnabled);
  }
  public CustomResourceColumnDefinitionBuilder(CustomResourceColumnDefinitionFluent<?> fluent,CustomResourceColumnDefinition instance) {
    this(fluent, instance, false);
  }
  public CustomResourceColumnDefinitionBuilder(CustomResourceColumnDefinitionFluent<?> fluent,CustomResourceColumnDefinition instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withJSONPath(instance.getJSONPath());
      fluent.withDescription(instance.getDescription());
      fluent.withFormat(instance.getFormat());
      fluent.withName(instance.getName());
      fluent.withPriority(instance.getPriority());
      fluent.withType(instance.getType());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public CustomResourceColumnDefinitionBuilder(CustomResourceColumnDefinition instance) {
    this(instance,false);
  }
  public CustomResourceColumnDefinitionBuilder(CustomResourceColumnDefinition instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withJSONPath(instance.getJSONPath());
      this.withDescription(instance.getDescription());
      this.withFormat(instance.getFormat());
      this.withName(instance.getName());
      this.withPriority(instance.getPriority());
      this.withType(instance.getType());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  CustomResourceColumnDefinitionFluent<?> fluent;
  Boolean validationEnabled;
  public CustomResourceColumnDefinition build() {
    CustomResourceColumnDefinition buildable = new CustomResourceColumnDefinition(fluent.getJSONPath(),fluent.getDescription(),fluent.getFormat(),fluent.getName(),fluent.getPriority(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> kubernetes-model-apiextensions-6.8.0-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1beta1/CustomResourceColumnDefinitionBuilder.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class CustomResourceColumnDefinitionBuilder extends CustomResourceColumnDefinitionFluent<CustomResourceColumnDefinitionBuilder> implements VisitableBuilder<CustomResourceColumnDefinition,CustomResourceColumnDefinitionBuilder>{
  public CustomResourceColumnDefinitionBuilder() {
    this(false);
  }
  public CustomResourceColumnDefinitionBuilder(Boolean validationEnabled) {
    this(new CustomResourceColumnDefinition(), validationEnabled);
  }
  public CustomResourceColumnDefinitionBuilder(CustomResourceColumnDefinitionFluent<?> fluent) {
    this(fluent, false);
  }
  public CustomResourceColumnDefinitionBuilder(CustomResourceColumnDefinitionFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new CustomResourceColumnDefinition(), validationEnabled);
  }
  public CustomResourceColumnDefinitionBuilder(CustomResourceColumnDefinitionFluent<?> fluent,CustomResourceColumnDefinition instance) {
    this(fluent, instance, false);
  }
  public CustomResourceColumnDefinitionBuilder(CustomResourceColumnDefinitionFluent<?> fluent,CustomResourceColumnDefinition instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new CustomResourceColumnDefinition());

    if (instance != null) {
      fluent.withJSONPath(instance.getJSONPath());
      fluent.withDescription(instance.getDescription());
      fluent.withFormat(instance.getFormat());
      fluent.withName(instance.getName());
      fluent.withPriority(instance.getPriority());
      fluent.withType(instance.getType());
      fluent.withJSONPath(instance.getJSONPath());
      fluent.withDescription(instance.getDescription());
      fluent.withFormat(instance.getFormat());
      fluent.withName(instance.getName());
      fluent.withPriority(instance.getPriority());
      fluent.withType(instance.getType());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public CustomResourceColumnDefinitionBuilder(CustomResourceColumnDefinition instance) {
    this(instance,false);
  }
  public CustomResourceColumnDefinitionBuilder(CustomResourceColumnDefinition instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new CustomResourceColumnDefinition());

    if (instance != null) {
      this.withJSONPath(instance.getJSONPath());
      this.withDescription(instance.getDescription());
      this.withFormat(instance.getFormat());
      this.withName(instance.getName());
      this.withPriority(instance.getPriority());
      this.withType(instance.getType());
      this.withJSONPath(instance.getJSONPath());
      this.withDescription(instance.getDescription());
      this.withFormat(instance.getFormat());
      this.withName(instance.getName());
      this.withPriority(instance.getPriority());
      this.withType(instance.getType());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  CustomResourceColumnDefinitionFluent<?> fluent;
  Boolean validationEnabled;
  public CustomResourceColumnDefinition build() {
    CustomResourceColumnDefinition buildable = new CustomResourceColumnDefinition(fluent.getJSONPath(),fluent.getDescription(),fluent.getFormat(),fluent.getName(),fluent.getPriority(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
